@@ -5,12 +5,14 @@
 #'
 #' @export
 #' @rdname gpg_encrypt
+#' @family gpg
 #' @useDynLib gpg R_gpgme_encrypt R_gpgme_signed_encrypt
-#' @param file path to file or raw vector with data to encrypt / decrypt
-#' @param receiver key id or fingerprint for recepient
-#' @param signer (optional) key id or fingerprint for the sender to sign the message
-gpg_encrypt <- function(file, receiver, signer = NULL){
-  data <- file_or_raw(file)
+#' @param data path or raw vector with data to encrypt / decrypt
+#' @param receiver key id(s) or fingerprint(s) for recepient(s)
+#' @param signer (optional) key id(s) or fingerprint(s) for the sender(s) to sign
+#' the message
+gpg_encrypt <- function(data, receiver, signer = NULL){
+  data <- file_or_raw(data)
   stopifnot(is.character(receiver))
   if(length(signer)){
     stopifnot(is.character(signer))
@@ -22,12 +24,11 @@ gpg_encrypt <- function(file, receiver, signer = NULL){
 
 #' @export
 #' @rdname gpg_encrypt
-#' @param verify automatically checks that all signatures can be verified and raises an
-#' error otherwise
+#' @param verify automatically checks that all signatures (if any) can be verified and
+#' raises an error otherwise
 #' @useDynLib gpg R_gpgme_decrypt R_gpgme_signed_decrypt
-gpg_decrypt <- function(file, verify = TRUE){
-  pinentry_warning()
-  data <- file_or_raw(file)
+gpg_decrypt <- function(data, verify = TRUE){
+  data <- file_or_raw(data)
   if(isTRUE(verify)){
     .Call(R_gpgme_signed_decrypt, data)
   } else {
